@@ -21,21 +21,26 @@
 
 #include "../config.h"
 #include <gtk/gtk.h>
+#include "gettext.h"
 #include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
 #include "widgets.h"
+#include "show_info.h"
 #include "activate_button_clicked.h"
 #include "commands.h"
 
+extern int use_tls;
 extern int activated;
 
 
 
 void activate_button_clicked(struct w *widgets)
 {
-    gchar *start, *test;
+    gchar *info, *start, *test, *cert_path;
+    G_CONST_RETURN gchar *cert_dir;
+    gint active_index = 0;
 
     /* Remove the shutdown file if it exists */
     unlink(GP_SHUTMSG);
@@ -43,6 +48,27 @@ void activate_button_clicked(struct w *widgets)
     if( activated )
       return;
 
+    /* If certs are required but have not been generated we inform the user */
+    if( use_tls )
+    {
+	/* Check if secure FTP is enabled in the combo. If so, require certificates before start. */
+	active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[14]));
+	if( active_index != 1 ) /* '1' is Off */
+	{
+	    cert_dir  = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[15]));
+	    cert_path =  g_strdup_printf("%s/cert.pem", cert_dir);
+	    if( ! file_exists(cert_path) )
+	    {
+		info = g_strdup_printf(_("You need to generate certificates before you can start the server.\n"));
+		show_info(info);
+		g_free(info);
+		g_free(cert_path);
+		return;
+	    }
+	    g_free(cert_path);
+	}
+    }
+
     /* Start the server */
     start = g_strdup_printf("%s -c %s", PROFTPD_BINARY, PROFTPD_CONF);
     if( ! run_command(start) )
