@@ -125,7 +125,7 @@ void create_file_tab(struct w *widgets)
     GtkTreeViewColumn *filename_col = gtk_tree_view_column_new_with_attributes(_("Files"), file_cell_renderer, "text", 3, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->file_treeview), GTK_TREE_VIEW_COLUMN(filename_col));
 
-    GtkTreeViewColumn *hostname_col = gtk_tree_view_column_new_with_attributes(_("Hostname"), file_cell_renderer, "text", 4, NULL);
+    GtkTreeViewColumn *hostname_col = gtk_tree_view_column_new_with_attributes(_("Client"), file_cell_renderer, "text", 4, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->file_treeview), GTK_TREE_VIEW_COLUMN(hostname_col));
 
     GtkTreeViewColumn *sot_col = gtk_tree_view_column_new_with_attributes(_("Start of transfer"), file_cell_renderer, "text", 5, NULL);
