@@ -139,7 +139,7 @@ void create_import_window(struct w *widgets)
     import_hbox3 = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(import_vbox), import_hbox3, FALSE, FALSE, 0);
 
-    import_label2 = gtk_label_new(_("Add users to closed private directories below FTP home:"));
+    import_label2 = gtk_label_new(_("Add users to private directories below the FTP home directory:"));
     gtk_box_pack_start(GTK_BOX(import_hbox3), import_label2, FALSE, FALSE, 0);
     gtk_label_set_justify(GTK_LABEL(import_label2), GTK_JUSTIFY_LEFT);
     gtk_misc_set_alignment(GTK_MISC(import_label2), 0.02, 0.5);
