@@ -21,6 +21,7 @@
 
 #include "../config.h"
 #include <gtk/gtk.h>
+#include <string.h>
 #include "gettext.h"
 #include "support.h"
 #include "widgets.h"
@@ -34,15 +35,14 @@
 
 void create_main_window(struct w *widgets)
 {
-    gchar *info, *pixmap_directory;
+    gchar *info, *utf8, *pixmap_directory;
     GtkCellRenderer *pixbuf_cell_renderer;
     GdkPixbuf *pixbuf;
 
     /* Create the main window */
     widgets->main_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_window_set_position(GTK_WINDOW (widgets->main_window), GTK_WIN_POS_CENTER);
-//    gtk_widget_set_size_request(widgets->main_window, 720, -1); //500);
-    gtk_widget_set_size_request(widgets->main_window, -1 , 500); //500);
+    gtk_widget_set_size_request(widgets->main_window, -1 , 500);
 
     /* Set window information */
     info = g_strdup_printf("GADMIN-PROFTPD %s", VERSION);
@@ -54,7 +54,7 @@ void create_main_window(struct w *widgets)
     add_pixmap_directory(pixmap_directory);
     g_free(pixmap_directory);
 
-    pixbuf_cell_renderer = gtk_cell_renderer_pixbuf_new();    
+    pixbuf_cell_renderer = gtk_cell_renderer_pixbuf_new();
     pixbuf = create_pixbuf("gadmin-proftpd.png");
     g_object_set(pixbuf_cell_renderer, "pixbuf", pixbuf, NULL); 
     gtk_window_set_icon(GTK_WINDOW(widgets->main_window), pixbuf);
@@ -83,89 +83,125 @@ void create_main_window(struct w *widgets)
 
     gtk_toolbar_set_style(GTK_TOOLBAR(main_toolbar), GTK_TOOLBAR_BOTH);
 
-    /* Activate button */    
-    GtkWidget *toolbar_icon_yes = gtk_image_new_from_stock("gtk-yes", 
+
+
+    /* Activate button */
+    info = g_strdup_printf(_("Activate"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    g_free(info);
+    GtkWidget *toolbar_icon_yes = gtk_image_new_from_stock("gtk-yes",
                                   gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *activate_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
                                                           GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Activate"), 
+							  NULL, utf8,
 							  NULL, NULL,
 							  toolbar_icon_yes, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(activate_button), "clicked", 
+    g_signal_connect_swapped(G_OBJECT(activate_button), "clicked",
                              G_CALLBACK(activate_button_clicked), widgets);
+    if( utf8!=NULL )
+      g_free(utf8);
+
 
     /* Deactivate button */
-    GtkWidget *toolbar_icon_no = gtk_image_new_from_stock("gtk-no", 
+    info = g_strdup_printf(_("Deactivate"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    g_free(info);
+    GtkWidget *toolbar_icon_no = gtk_image_new_from_stock("gtk-no",
                                  gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *deactivate_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
                                                           GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Deactivate"),
+							  NULL, utf8,
 							  NULL, NULL,
 							  toolbar_icon_no, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(deactivate_button), "clicked", 
+    g_signal_connect_swapped(G_OBJECT(deactivate_button), "clicked",
                              G_CALLBACK(deactivate_button_clicked), widgets);
+    if( utf8!=NULL )
+      g_free(utf8);
 
 
     /* Shutdown button */
-    GtkWidget *toolbar_icon_stop = gtk_image_new_from_stock("gtk-stop", 
+    info = g_strdup_printf(_("Shutdown"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    g_free(info);
+    GtkWidget *toolbar_icon_stop = gtk_image_new_from_stock("gtk-stop",
                                       gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *shutdown_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
                                                           GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Shutdown"),
+							  NULL, utf8,
 							  NULL, NULL,
 							  toolbar_icon_stop, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(shutdown_button), "clicked", 
+    g_signal_connect_swapped(G_OBJECT(shutdown_button), "clicked",
                              G_CALLBACK(show_shutdown), widgets);
+    if( utf8!=NULL )
+      g_free(utf8);
 
 
     /* Apply button */
+    info = g_strdup_printf(_("Apply"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    g_free(info);
     GtkWidget *toolbar_icon_apply = gtk_image_new_from_stock("gtk-apply", 
                                       gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *apply_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
                                                           GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Apply"),
+							  NULL, utf8,
 							  NULL, NULL,
 							  toolbar_icon_apply, NULL, NULL);
     g_signal_connect_swapped(G_OBJECT(apply_button), "clicked", 
                              G_CALLBACK(apply_button_clicked), widgets);
-
-    /*  gtk_toolbar_append_space(GTK_TOOLBAR(main_toolbar)); */
+    if( utf8!=NULL )
+      g_free(utf8);
 
 
     /* Help button */
-    GtkWidget *toolbar_icon_help = gtk_image_new_from_stock("gtk-help", 
+    info = g_strdup_printf(_("Help"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    g_free(info);
+    GtkWidget *toolbar_icon_help = gtk_image_new_from_stock("gtk-help",
                                    gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *help_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
                                                           GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Help"),
+							  NULL, utf8,
 							  NULL, NULL,
 							  toolbar_icon_help, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(help_button), "clicked", 
+    g_signal_connect_swapped(G_OBJECT(help_button), "clicked",
                              G_CALLBACK(show_help), widgets);
+    if( utf8!=NULL )
+      g_free(utf8);
 
 
-    /* About/Credits button */
-    GtkWidget *toolbar_icon_about = gtk_image_new_from_stock("gtk-justify-center", 
+    /* About button */
+    info = g_strdup_printf(_("About"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    g_free(info);
+    GtkWidget *toolbar_icon_about = gtk_image_new_from_stock("gtk-justify-center",
                                       gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *about_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
                                                           GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("About"),
+							  NULL, utf8,
 							  NULL, NULL,
 							  toolbar_icon_about, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(about_button), "clicked", 
+    g_signal_connect_swapped(G_OBJECT(about_button), "clicked",
                              G_CALLBACK(show_credits), widgets);
+    if( utf8!=NULL )
+      g_free(utf8);
 
 
     /* Quit button */
-    GtkWidget *toolbar_icon_quit = gtk_image_new_from_stock("gtk-quit", 
+    info = g_strdup_printf(_("Quit"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    g_free(info);
+    GtkWidget *toolbar_icon_quit = gtk_image_new_from_stock("gtk-quit",
                                    gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *quit_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
                                                           GTK_TOOLBAR_CHILD_BUTTON,
-							  NULL, _("Quit"),
+							  NULL, utf8,
 							  NULL, NULL,
 							  toolbar_icon_quit, NULL, NULL);
-    g_signal_connect_swapped(G_OBJECT(quit_button), "clicked", 
+    g_signal_connect_swapped(G_OBJECT(quit_button), "clicked",
                              G_CALLBACK(gtk_main_quit), NULL);
+    if( utf8!=NULL )
+      g_free(utf8);
 
     /* The notebook */
     GtkWidget *notebook_vbox = gtk_vbox_new(FALSE, 0);
@@ -183,13 +219,59 @@ void create_main_window(struct w *widgets)
     gtk_box_pack_start(GTK_BOX(notebook_vbox), main_notebook, TRUE, TRUE, 0);
     gtk_notebook_set_show_border(GTK_NOTEBOOK(main_notebook), TRUE);
 
-    GtkWidget *server_label   = gtk_label_new(_("Servers"));
-    GtkWidget *user_label     = gtk_label_new(_("Users"));
-    GtkWidget *transfer_label = gtk_label_new(_("Transfers"));
-    GtkWidget *disc_label     = gtk_label_new(_("Disc"));
-    GtkWidget *file_label     = gtk_label_new(_("Files"));
-    GtkWidget *security_label = gtk_label_new(_("Security"));
-    GtkWidget *conf_label     = gtk_label_new(_("Configuration"));
+    info = g_strdup_printf(_("Servers"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    g_free(info);
+    GtkWidget *server_label = gtk_label_new(utf8);
+    if( utf8!=NULL )
+      g_free(utf8);
+
+    info = g_strdup_printf(_("Users"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    g_free(info);
+    GtkWidget *user_label = gtk_label_new(utf8);
+    if( utf8!=NULL )
+      g_free(utf8);
+
+    info = g_strdup_printf(_("Transfers"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    g_free(info);
+    GtkWidget *transfer_label = gtk_label_new(utf8);
+    if( utf8!=NULL )
+      g_free(utf8);
+
+
+    info = g_strdup_printf(_("Disc"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    g_free(info);
+    GtkWidget *disc_label = gtk_label_new(utf8);
+    if( utf8!=NULL )
+      g_free(utf8);
+
+
+    info = g_strdup_printf(_("Files"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    g_free(info);
+    GtkWidget *file_label = gtk_label_new(utf8);
+    if( utf8!=NULL )
+      g_free(utf8);
+
+
+    info = g_strdup_printf(_("Security"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    g_free(info);
+    GtkWidget *security_label = gtk_label_new(utf8);
+    if( utf8!=NULL )
+      g_free(utf8);
+
+
+    info = g_strdup_printf(_("Configuration"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    g_free(info);
+    GtkWidget *conf_label = gtk_label_new(utf8);
+    if( utf8!=NULL )
+      g_free(utf8);
+
 
     gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox1, server_label, 0);
     gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox2, user_label, 1);
@@ -199,19 +281,30 @@ void create_main_window(struct w *widgets)
     gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox6, security_label, 5);
     gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox7, conf_label, 6);
 
+
     /* Set version and status labels */
-    widgets->version_label = gtk_label_new(_("Information: cant read version"));
+    info = g_strdup_printf(_("Information: cant read version"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    g_free(info);
+    widgets->version_label = gtk_label_new(utf8);
     gtk_box_pack_start(GTK_BOX(status_hbox), widgets->version_label, FALSE, FALSE, 0);
     gtk_misc_set_alignment(GTK_MISC(widgets->version_label), 0, 0);
+    if( utf8!=NULL )
+      g_free(utf8);
 
 
     GtkWidget *status_spacer_label = gtk_label_new("");
     gtk_box_pack_start(GTK_BOX(status_hbox), status_spacer_label, TRUE, TRUE, 0);
     gtk_misc_set_alignment (GTK_MISC (status_spacer_label), 0, 0);
 
+    info = g_strdup_printf(_("Status: unknown"));
+    utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
+    g_free(info);
     widgets->status_label = gtk_label_new(_("Status: unknown"));
     gtk_box_pack_start(GTK_BOX(status_hbox), widgets->status_label, FALSE, FALSE, 0);
     gtk_misc_set_alignment(GTK_MISC(widgets->status_label), 0, 0);
+    if( utf8!=NULL )
+      g_free(utf8);
 
     GtkWidget *status_hseparator = gtk_hseparator_new();
     gtk_box_pack_start(GTK_BOX(status_hsep_hbox), status_hseparator, TRUE, TRUE, 0);
