@@ -62,7 +62,7 @@ void restrict_pam_conf(int add_del)
     fseek(fp, 0, SEEK_END);
     file_size = ftell(fp);
     rewind(fp);
-				    
+
     line     = allocate(file_size+1);
     new_conf = allocate(file_size+1024);
 
@@ -171,13 +171,15 @@ void create_server_settings(struct w *widgets)
 
 
     /* The server address */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Servers address: "), 0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("ftp.mydomain.org, 192.168.0.100 or 0.0.0.0 meaning listen to all network interfaces"), NULL);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Server address:"), 0,1,a,b,entry_size);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
+    _("ftp.mydomain.org, 192.168.0.100 or 0.0.0.0 which means listen to all network interfaces"), NULL);
     a++; b++; ent++;
 
-    /* Alternative server ident Label+Entry+Combo */
-    widgets->server_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Server name: "), 0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("My FTP server or set it to off to have the server use its own name and version"), NULL);
+    /* Server name / Alternative server ident Label+Entry+Combo */
+    widgets->server_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Server name:"), 0,1,a,b,entry_size);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
+    _("My FTP server or set it to off to have the server use its own name and version"), NULL);
 
     widgets->server_set_combo[comb] = make_combo(GTK_TABLE(widgets->srv_set_table), 1,2,a,b,combo_size);
     combo_text = g_strdup_printf(_("On"));
@@ -189,9 +191,16 @@ void create_server_settings(struct w *widgets)
     g_free(combo_text); g_free(utf8);
     a++; b++; ent++; comb++;
 
+    /* Port */
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_("Server port:"), 0,1,a,b,50);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin],
+    _("A port the server listens on. 21 is the standard port. 0 means that the server is deactivated"), NULL);
+    a++; b++; spin++;
+
     /* Nat router Label+Entry+Combo */
-    widgets->server_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" NAT router: "), 0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The public IP or DNS name of the NAT router, IE: router.mydomain.org or 192.168.0.100"), NULL);
+    widgets->server_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("NAT router:"), 0,1,a,b,entry_size);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
+    _("The external IP address or DNS name of the NAT router."), NULL);
 
     widgets->server_set_combo[comb] = make_combo(GTK_TABLE(widgets->srv_set_table), 1,2,a,b,combo_size);
     combo_text = g_strdup_printf(_("On"));
@@ -204,12 +213,12 @@ void create_server_settings(struct w *widgets)
     a++; b++; ent++; comb++;
 
     /* Email */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Admin email: "), 0,1,a,b,200);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Admin email:"), 0,1,a,b,200);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The administrators email address"), NULL);
     a++; b++; ent++;
 
     /* Identity lookups */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Identity lookups: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _("Identity lookups:"), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("On"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -220,7 +229,7 @@ void create_server_settings(struct w *widgets)
     a++; b++; comb++;
 
     /* Reverse lookups */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Reverse lookups: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _("Reverse lookups:"), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("On"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -231,7 +240,7 @@ void create_server_settings(struct w *widgets)
     a++; b++; comb++;
 
     /* Time standard */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),_(" Time standard: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),_("Time standard:"), 0,1,a,b,50);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_combo[comb], _("GMT or local time"), NULL);
     combo_text = g_strdup_printf(_("GMT"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
@@ -242,13 +251,8 @@ void create_server_settings(struct w *widgets)
     g_free(combo_text); g_free(utf8);
     a++; b++; comb++;
 
-    /* Port */    
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Port: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("The port the server listens on. 21 is the standard port. 0 means deactivated"), NULL);
-    a++; b++; spin++;
-
     /* Passive ports */
-    widgets->server_set_spinbutton[spin] = make_padded_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table), _(" Passive port range: "), 0,1,a,b,50);
+    widgets->server_set_spinbutton[spin] = make_padded_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table), _("Passive port range:"), 0,1,a,b,50);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("From this port"), NULL);
     spin++;
     widgets->server_set_spinbutton[spin] = make_spinbutton(GTK_TABLE(widgets->srv_set_table), 0,1,a,b,50);
@@ -256,27 +260,27 @@ void create_server_settings(struct w *widgets)
     a++; b++; spin++;
 
     /* Max connections */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Max connections: "), 0,1,a,b,50);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_("Max connections:"), 0,1,a,b,50);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("The maximum simoultaneous connections for this server"), NULL);
     a++; b++; spin++;
 
     /* Maximum logins */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Max login tries: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("The maximum number of logins a user can fail before disconnected"), NULL);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_("Max login attempts:"), 0,1,a,b,50);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("The maximum number of logins attempts a user can fail before disconnected"), NULL);
     a++; b++; spin++;
 
     /* Login timeout */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Login timeout: "), 0,1,a,b,50);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_("Login timeout:"), 0,1,a,b,50);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("The maximum time a user can spend authenticating"), NULL);
     a++; b++; spin++;
 
     /* Idle timeout */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Idle timeout: "), 0,1,a,b,50);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_("Idle timeout:"), 0,1,a,b,50);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("The time it takes before an idle user is thrown out in seconds"), NULL);
     a++; b++; spin++;
 
     /* Transfer mode */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Transfer mode: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _("Transfer mode:"), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("Binary"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -287,7 +291,7 @@ void create_server_settings(struct w *widgets)
     a++; b++; comb++;
 
     /* FXP transfers */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" FXP transfers: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _("FXP transfers:"), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("On"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -302,17 +306,17 @@ void create_server_settings(struct w *widgets)
 // The following should be added to a settings window....
 
     /* Randomized username length */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Randomized username length: "), 0,1,a,b,50);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_("Username length:"), 0,1,a,b,50);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("The length of the randomized usernames"), NULL);
     a++; b++; spin++;
 
     /* Randomized password length */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Randomized password length: "), 0,1,a,b,50);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_("Password length:"), 0,1,a,b,50);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("The length of the randomized passwords"), NULL);
     a++; b++; spin++;
 
     /* Randomize case */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Randomize case: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _("Randomized letters:"), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("Upper"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -329,7 +333,7 @@ void create_server_settings(struct w *widgets)
     a++; b++; ent++;
 
     /* Enable or disable virtual users */
-    widgets->server_set_check_virtual = make_checkbutton_with_label(GTK_TABLE(widgets->srv_set_table), _(" Enable virtual users: "), 0,1,a,b);
+    widgets->server_set_check_virtual = make_checkbutton_with_label(GTK_TABLE(widgets->srv_set_table), _("Enable virtual users:"), 0,1,a,b);
     a++; b++;
 
     /* Add a callback that switches to / from virtual user paths and repopulates */
@@ -338,7 +342,7 @@ void create_server_settings(struct w *widgets)
 
 
     /* Statistics file */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" HTML statistics file: "), 0,1,a,b,200);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("HTML statistics:"), 0,1,a,b,200);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Generated HTML statistics file, IE: /var/www/ftp.htm"), NULL);
     a++; b++; ent++;
 
@@ -347,23 +351,24 @@ void create_server_settings(struct w *widgets)
 
 
     /* The systems security logfile */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" The systems security logfile: "), 0,1,a,b,200);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Security log:"), 0,1,a,b,200);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("IE: /var/log/secure"), NULL);
     a++; b++; ent++;
 
     /* The server runs as this user */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" The server runs as this user: "), 0,1,a,b,200);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Server user:"), 0,1,a,b,200);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The server drops its privileges and runs as this user, nobody is often used"), NULL);
     a++; b++; ent++;
 
     /* The server runs as this group */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" The server runs as this group: "), 0,1,a,b,200);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Server group:"), 0,1,a,b,200);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The server drops its privileges and runs as this group, nobody is often used"), NULL);
     a++; b++; ent++;
 
     /* This fake user owns all files Label+Entry+Combo */
-    widgets->server_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" This fake user owns all files: "),     0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Doesnt have to be an existing user"), NULL);
+    widgets->server_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Fake file user:"),     0,1,a,b,entry_size);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
+    _("It will look like this fake user owns all files.\nIt does not have to be an existing user"), NULL);
 
     widgets->server_set_combo[comb] = make_combo(GTK_TABLE(widgets->srv_set_table), 1,2,a,b,combo_size);
     combo_text = g_strdup_printf(_("On"));
@@ -376,8 +381,9 @@ void create_server_settings(struct w *widgets)
     a++; b++; ent++; comb++;
 
     /* This fake group owns all files Label+Entry+Combo */
-    widgets->server_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" This fake group owns all files: "),     0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Doesnt have to be an existing group"), NULL);
+    widgets->server_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Fake file group:"),     0,1,a,b,entry_size);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
+    _("It will look like this fake group owns all files.\nIt does not have to be an existing group"), NULL);
 
     widgets->server_set_combo[comb] = make_combo(GTK_TABLE(widgets->srv_set_table), 1,2,a,b,combo_size);
     combo_text = g_strdup_printf(_("On"));
@@ -390,17 +396,17 @@ void create_server_settings(struct w *widgets)
     a++; b++; ent++; comb++;
 
     /* Upload speed */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Upload speed: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Total upload speed shared by all clients"), NULL);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_("Upload speed:"), 0,1,a,b,50);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Total upload speed shared by all clients in KiloBytes/sec"), NULL);
     a++; b++; spin++;
 
     /* Download speed */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Download speed: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Total download speed shared by all clients"), NULL);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_("Download speed:"), 0,1,a,b,50);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Total download speed shared by all clients in KiloBytes/sec"), NULL);
     a++; b++; spin++;
 
     /* Resume broken uploads */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Allow Resume of broken uploads: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _("Resume uploads:"), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("On"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -411,7 +417,7 @@ void create_server_settings(struct w *widgets)
     a++; b++; comb++;
 
     /* Resume broken downloads */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Allow Resume of broken downloads: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _("Resume downloads:"), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("On"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -422,7 +428,7 @@ void create_server_settings(struct w *widgets)
     a++; b++; comb++;
 
     /* Remove aborted uploads */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Remove aborted uploads: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _("Remove aborted uploads:"), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("On"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -441,11 +447,11 @@ void create_server_settings(struct w *widgets)
 	a++; b++;
 	
 	/* Secure communications label */
-	make_3columns_label(GTK_TABLE(widgets->srv_set_table), _(" Secure communications: "), 0,1,a,b);
+	make_3columns_label(GTK_TABLE(widgets->srv_set_table), _("Secure communications:"), 0,1,a,b);
 	a++; b++;
 
 	/* Use secure communication */
-	widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Use secure communication: "), 0,1,a,b,50);
+	widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _("Use secure communication:"), 0,1,a,b,50);
 	combo_text = g_strdup_printf(_("On"));
 	utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
 	gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -456,7 +462,7 @@ void create_server_settings(struct w *widgets)
 	a++; b++; comb++;
 
 	/* Require encryption on channels */
-	widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Require encryption on channels: "), 0,1,a,b,50);
+	widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _("Require for channels:"), 0,1,a,b,50);
 	combo_text = g_strdup_printf(_("Both"));
 	utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
 	gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -473,7 +479,7 @@ void create_server_settings(struct w *widgets)
 	a++; b++; comb++;
 
 	/* Verify clients */
-	widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Verify clients: "), 0,1,a,b,50);
+	widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _("Verify clients:"), 0,1,a,b,50);
 	combo_text = g_strdup_printf(_("On"));
 	utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
 	gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -484,12 +490,12 @@ void create_server_settings(struct w *widgets)
 	a++; b++; comb++;
 
 	/* Use these protocols */
-	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Use these protocols: "), 0,1,a,b,200);
+	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Use these protocols:"), 0,1,a,b,200);
 	gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("IE: SSLv23 or TLSv1"), NULL);
 	a++; b++; ent++;
 
-	/* The TLS logfile */
-	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" The TLS logfile: "), 0,1,a,b,200);
+	/* The TLS log */
+	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("TLS log:"), 0,1,a,b,200);
 	gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("IE: /var/log/gadmin-proftpd_tls.log"), NULL);
 	a++; b++; ent++;
 
@@ -502,43 +508,43 @@ void create_server_settings(struct w *widgets)
 	a++; b++;
 
 	/* The certificate directory */
-	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Certificate directory: "), 0,1,a,b,200);
+	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Certificate directory:"), 0,1,a,b,200);
 	gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("IE: /etc/gadmin-proftpd/certs"), NULL);
 	a++; b++; ent++;
 
 
 	/* This servers DNS name or IP-Address */
-	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Server address: "), 0,1,a,b,200);
+	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Server address:"), 0,1,a,b,200);
 	gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("This servers DNS name or IP address"), NULL);
 	a++; b++; ent++;
 
 	/* Email address */
-	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Email address: "), 0,1,a,b,200);
+	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Email address:"), 0,1,a,b,200);
 	gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The administrators email address"), NULL);
 	a++; b++; ent++;
 
 	/* Country */
-	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Country: "), 0,1,a,b,200);
+	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Country:"), 0,1,a,b,200);
 	gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("A country"), NULL);
 	a++; b++; ent++;
 
 	/* City or town */
-	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" City or town: "), 0,1,a,b,200);
+	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("City or town:"), 0,1,a,b,200);
 	gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("A city or a town"), NULL);
 	a++; b++; ent++;
 
 	/* Organization */
-	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Organization: "), 0,1,a,b,200);
+	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Organization:"), 0,1,a,b,200);
 	gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Some organization"), NULL);
 	a++; b++; ent++;
 
 	/* Organizational unit */
-	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Organizational unit: "), 0,1,a,b,200);
+	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Organizational unit:"), 0,1,a,b,200);
 	gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Accounting"), NULL);
 	a++; b++; ent++;
 
 	/* Password */
-	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Password: "), 0,1,a,b,200);
+	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Password:"), 0,1,a,b,200);
 	gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("A password"), NULL);
 	a++; b++; ent++;
 
@@ -546,23 +552,23 @@ void create_server_settings(struct w *widgets)
 	a++; b++; ent++;
 
 	/* Encryption bits (Min value = 384) */
-	widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Encryption bits: "), 0,1,a,b,50);
+	widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_("Encryption bits:"), 0,1,a,b,50);
 	gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Number of bits in the generated certificate"), NULL);
 	gtk_spin_button_set_range(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[spin]), 384, 999999);
 	a++; b++; spin++;
 
 	/* Number of days the certificate is valid */
-	widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Days valid: "), 0,1,a,b,50);
+	widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_("Days valid:"), 0,1,a,b,50);
 	gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Number of days the certificate is valid"), NULL);
 	a++; b++; spin++;
 
 	/* Countrycode */
-	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Country code IE: SV, DK, DE, EN, US: "), 0,1,a,b,200);
-	gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The country code"), NULL);
+	widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _("Country code:"), 0,1,a,b,200);
+	gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The country code, IE: SV, DK, EN, US, etc"), NULL);
 	a++; b++; ent++;
 
 	/* A progress bar */
-	widgets->gen_cert_progressbar = make_progressbar_with_label(GTK_TABLE(widgets->srv_set_table), _(" Generate new certificates: "), 0,1,a,b,210);
+	widgets->gen_cert_progressbar = make_progressbar_with_label(GTK_TABLE(widgets->srv_set_table), _("Generate new certificates:"), 0,1,a,b,210);
 	gtk_widget_set_sensitive(widgets->gen_cert_progressbar, FALSE);
 
 	/* The progress bar looks nicer if its blue from start */
@@ -587,11 +593,11 @@ void create_server_settings(struct w *widgets)
 	a++; b++;
 	
 	/* Ratio label */
-	make_3columns_label(GTK_TABLE(widgets->srv_set_table), _(" Ratios for uploads and downloads: "), 0,1,a,b);
+	make_3columns_label(GTK_TABLE(widgets->srv_set_table), _("Ratios for uploads and downloads:"), 0,1,a,b);
 	a++; b++;
 
 	/* Use Ratios */
-	widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Use Ratios: "), 0,1,a,b,50);
+	widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _("Use ratios:"), 0,1,a,b,50);
 	combo_text = g_strdup_printf(_("On"));
 	utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
 	gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -602,7 +608,7 @@ void create_server_settings(struct w *widgets)
 	a++; b++; comb++;
 
 	/* Save Ratios */
-	widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Save Ratios: "), 0,1,a,b,50);
+	widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _("Save ratios:"), 0,1,a,b,50);
 	combo_text = g_strdup_printf(_("On"));
 	utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
 	gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
