@@ -80,19 +80,19 @@ void create_server_tab(struct w *widgets)
     /* Set the column labels in the treeview */
     server_cell_renderer = gtk_cell_renderer_text_new();
 
-    GtkTreeViewColumn *address_col = gtk_tree_view_column_new_with_attributes(_("Address"), server_cell_renderer, "text", 0, NULL);
+    GtkTreeViewColumn *address_col = gtk_tree_view_column_new_with_attributes(_("Server address"), server_cell_renderer, "text", 0, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->server_treeview), GTK_TREE_VIEW_COLUMN(address_col));
 
     GtkTreeViewColumn *port_col = gtk_tree_view_column_new_with_attributes(_("Port"), server_cell_renderer, "text", 1, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->server_treeview), GTK_TREE_VIEW_COLUMN(port_col));
 
-    GtkTreeViewColumn *server_name_col = gtk_tree_view_column_new_with_attributes(_("Server Name"), server_cell_renderer, "text", 2, NULL);
+    GtkTreeViewColumn *server_name_col = gtk_tree_view_column_new_with_attributes(_("Server name"), server_cell_renderer, "text", 2, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->server_treeview), GTK_TREE_VIEW_COLUMN(server_name_col));
 
-    GtkTreeViewColumn *server_type_col = gtk_tree_view_column_new_with_attributes(_("Server Type"), server_cell_renderer, "text", 3, NULL);
+    GtkTreeViewColumn *server_type_col = gtk_tree_view_column_new_with_attributes(_("Server type"), server_cell_renderer, "text", 3, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->server_treeview), GTK_TREE_VIEW_COLUMN(server_type_col));
 
-    g_signal_connect((gpointer)widgets->server_treeview, "button_press_event",  
+    g_signal_connect((gpointer)widgets->server_treeview, "button_press_event",
 		      G_CALLBACK(server_treeview_row_clicked), widgets);
 
 
@@ -119,7 +119,7 @@ void create_server_tab(struct w *widgets)
     gtk_widget_show (import_image);
     gtk_box_pack_start(GTK_BOX(import_hbox), import_image, FALSE, FALSE, 0);
 
-    import_label = gtk_label_new_with_mnemonic(_("Import users"));
+    import_label = gtk_label_new_with_mnemonic(_("Import"));
     gtk_widget_show (import_label);
     gtk_box_pack_start(GTK_BOX(import_hbox), import_label, FALSE, FALSE, 0);
     gtk_label_set_justify(GTK_LABEL(import_label), GTK_JUSTIFY_LEFT);
@@ -165,7 +165,7 @@ void create_server_tab(struct w *widgets)
     gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(widgets->server_settings_scrolled_window), widgets->server_settings_vbox);
 
     /* Add a frame */
-    frame = gtk_frame_new(_("Server settings"));
+    frame = gtk_frame_new(_("Settings"));
 
     /* Add a table with for the settings with 3 columns */
     widgets->srv_set_table = gtk_table_new(NUM_SERVERTAB_ENTRIES+NUM_SERVERTAB_SPINBUTTONS+NUM_SERVERTAB_COMBOS, 3, FALSE);
