@@ -30,7 +30,7 @@
 
 #define EXPAND_TRANSFER_SECTION 1
 
-void transfer_treeview_row_clicked(GtkTreeView *treeview, GdkEventButton *event, struct w *widgets) //gpointer data)
+void transfer_treeview_row_clicked(GtkTreeView *treeview, GdkEventButton *event, struct w *widgets)
 {
     gchar *pid, *username;
     GtkTreeIter iter;
@@ -88,8 +88,8 @@ void create_transfer_tab(struct w *widgets)
 
     transfer_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
     gtk_box_pack_start(GTK_BOX(transfer_treeview_hbox), transfer_scrolled_window, TRUE, TRUE, 0);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(transfer_scrolled_window), 
-						    GTK_POLICY_AUTOMATIC, 
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(transfer_scrolled_window),
+						    GTK_POLICY_AUTOMATIC,
 						    GTK_POLICY_ALWAYS);
 
     widgets->transfer_store = gtk_list_store_new(8, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, 
@@ -113,7 +113,7 @@ void create_transfer_tab(struct w *widgets)
     GtkTreeViewColumn *action_col = gtk_tree_view_column_new_with_attributes(_("Action"), transfer_cell_renderer, "text", 2, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->transfer_treeview), GTK_TREE_VIEW_COLUMN(action_col));
 
-    GtkTreeViewColumn *speed_col = gtk_tree_view_column_new_with_attributes(_("KB/s"), transfer_cell_renderer, "text", 3, NULL);
+    GtkTreeViewColumn *speed_col = gtk_tree_view_column_new_with_attributes(_("KiloBytes/sec"), transfer_cell_renderer, "text", 3, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->transfer_treeview), GTK_TREE_VIEW_COLUMN(speed_col));
 
     GtkTreeViewColumn *dir_col = gtk_tree_view_column_new_with_attributes(_("Directory"), transfer_cell_renderer, "text", 4, NULL);
@@ -129,7 +129,7 @@ void create_transfer_tab(struct w *widgets)
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->transfer_treeview), GTK_TREE_VIEW_COLUMN(server_col));
 
     /* Treeview clicked callback */
-    g_signal_connect((gpointer)widgets->transfer_treeview, "button_press_event",  
+    g_signal_connect((gpointer)widgets->transfer_treeview, "button_press_event",
 	        		G_CALLBACK(transfer_treeview_row_clicked), widgets);
 
 
@@ -137,7 +137,7 @@ void create_transfer_tab(struct w *widgets)
     GtkWidget *speed_hbox = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox3), speed_hbox, FALSE, FALSE, 0);
 
-    /* Transfer speed labels */
+    /* Transfer speed labels. Text and speeds are added in status_update. */
     widgets->total_bandwidth_label = gtk_label_new("");
     widgets->total_incoming_label  = gtk_label_new("");
     widgets->total_outgoing_label  = gtk_label_new("");
@@ -150,15 +150,15 @@ void create_transfer_tab(struct w *widgets)
     GtkWidget *kick_hbox1 = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox3), kick_hbox1, FALSE, FALSE, 0);
 
-    GtkWidget *kick_entry_label = gtk_label_new(" Username or PID to kick or kickban: ");
+    GtkWidget *kick_entry_label = gtk_label_new("Username or PID to kick or kickban:");
     widgets->kick_entry = gtk_entry_new();
 
     gtk_box_pack_start(GTK_BOX(kick_hbox1), kick_entry_label, FALSE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(kick_hbox1), widgets->kick_entry, FALSE, FALSE, 0);
 
     /* Togglebutton for selecting pid instead of user */
-    GtkWidget *selection_label = gtk_label_new(_(" Select PID: "));
-    widgets->transfer_pid_checkbutton = gtk_check_button_new(); //_with_mnemonic(_(" Select PID: "));
+    GtkWidget *selection_label = gtk_label_new(_("Select PID:"));
+    widgets->transfer_pid_checkbutton = gtk_check_button_new();
 
     gtk_box_pack_start(GTK_BOX(kick_hbox1), selection_label, FALSE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(kick_hbox1), widgets->transfer_pid_checkbutton, FALSE, FALSE, 0);
@@ -214,144 +214,3 @@ void create_transfer_tab(struct w *widgets)
 
     gtk_widget_show_all(widgets->main_window);
 }
-
-
-
-
-
-
-
-
-
-/* Create the transfer textview in a scrolled window */
-/*
-void create_transfer_tab(struct w *widgets)
-{
-    GtkWidget *transfer_hbox[4], *transfer_scrolled_window;
-
-    GtkWidget *top_spacer_label = gtk_label_new("");
-
-    GtkWidget *right_spacer_label[3];
-    right_spacer_label[0] = gtk_label_new("   ");
-    right_spacer_label[1] = gtk_label_new("   ");
-    right_spacer_label[2] = gtk_label_new("   ");
-
-    GtkWidget *total_bandwidth_label = gtk_label_new(" Total transfer rate: ");
-    GtkWidget *total_incoming_label = gtk_label_new(" Total incoming: ");
-    GtkWidget *total_outgoing_label = gtk_label_new(" Total outgoing: ");
-    widgets->total_bandwidth_entry = gtk_entry_new();
-    widgets->total_incoming_entry = gtk_entry_new();
-    widgets->total_outgoing_entry = gtk_entry_new();
-    widgets->kick_entry = gtk_entry_new();
-
-    GtkWidget *kick_descr_label = gtk_label_new(" Username or Process ID: ");
-    GtkWidget *kick_label, *kickban_label;
-    GtkWidget *kick_button, *kickban_button;
-    GtkWidget *kick_hbox, *kickban_hbox;
-    GtkWidget *kick_image, *kickban_image;
-    GtkWidget *kick_alignment, *kickban_alignment;
-    
-
-    transfer_hbox[0] = gtk_hbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox3), transfer_hbox[0], FALSE, FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(transfer_hbox[0]), top_spacer_label, FALSE, FALSE, 0);
-
-
-    transfer_hbox[1] = gtk_hbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox3), transfer_hbox[1], FALSE, FALSE, 0);
-
-    gtk_box_pack_start(GTK_BOX(transfer_hbox[1]), total_bandwidth_label, FALSE, FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(transfer_hbox[1]), widgets->total_bandwidth_entry, TRUE, TRUE, 0);
-    gtk_widget_set_sensitive(widgets->total_bandwidth_entry, FALSE);    
-
-    gtk_box_pack_start(GTK_BOX(transfer_hbox[1]), right_spacer_label[0], TRUE, TRUE, 0);
-
-
-    transfer_hbox[2] = gtk_hbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox3), transfer_hbox[2], FALSE, FALSE, 0);
-
-    gtk_box_pack_start(GTK_BOX(transfer_hbox[2]), total_incoming_label, FALSE, FALSE, 0);
-    gtk_misc_set_alignment(GTK_MISC(total_incoming_label), 0, 0.5);
-
-    gtk_box_pack_start(GTK_BOX(transfer_hbox[2]), widgets->total_incoming_entry, TRUE, TRUE, 0);
-    gtk_widget_set_sensitive(widgets->total_incoming_entry, FALSE);    
-
-    gtk_box_pack_start(GTK_BOX(transfer_hbox[2]), total_outgoing_label, FALSE, FALSE, 0);
-    gtk_misc_set_alignment(GTK_MISC(total_outgoing_label), 0, 0.5);
-
-    gtk_box_pack_start(GTK_BOX(transfer_hbox[2]), widgets->total_outgoing_entry, TRUE, TRUE, 0);
-    gtk_widget_set_sensitive(widgets->total_outgoing_entry, FALSE);
-
-    gtk_box_pack_start(GTK_BOX(transfer_hbox[2]), right_spacer_label[1], TRUE, TRUE, 0);
-
-
-    transfer_hbox[3] = gtk_hbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox3), transfer_hbox[3], FALSE, TRUE, 0);
-    
-    gtk_box_pack_start(GTK_BOX(transfer_hbox[3]), kick_descr_label, FALSE, FALSE, 0);
-    gtk_misc_set_alignment(GTK_MISC(kick_descr_label), 0, 0.5);
-
-    widgets->kick_entry = gtk_entry_new();
-    gtk_box_pack_start(GTK_BOX(transfer_hbox[3]), widgets->kick_entry, TRUE, TRUE, 0);
-
-    kick_button = gtk_button_new();
-    kick_alignment = gtk_alignment_new (0.5, 0.5, 0, 0);
-    gtk_container_add(GTK_CONTAINER(kick_button), kick_alignment);
-
-    kick_hbox = gtk_hbox_new(FALSE, 2);
-    gtk_container_add(GTK_CONTAINER(kick_alignment), kick_hbox);
-
-    kick_image = gtk_image_new_from_stock("gtk-apply", GTK_ICON_SIZE_BUTTON);
-    gtk_box_pack_start(GTK_BOX(kick_hbox), kick_image, FALSE, FALSE, 0);
-
-    kick_label = gtk_label_new_with_mnemonic(_("Kick"));
-    gtk_box_pack_start(GTK_BOX(kick_hbox), kick_label, FALSE, FALSE, 0);
-
-    gtk_label_set_justify(GTK_LABEL(kick_label), GTK_JUSTIFY_LEFT);
-
-    gtk_box_pack_start(GTK_BOX(transfer_hbox[3]), kick_button, FALSE, FALSE, 0);
-    g_signal_connect_swapped(GTK_OBJECT(kick_button), "clicked",
-			     G_CALLBACK(kick_button_clicked), widgets);
-
-
-    kickban_button = gtk_button_new();
-    kickban_alignment = gtk_alignment_new (0.5, 0.5, 0, 0);
-    gtk_container_add(GTK_CONTAINER(kickban_button), kickban_alignment);
-
-    kickban_hbox = gtk_hbox_new(FALSE, 2);
-    gtk_container_add(GTK_CONTAINER(kickban_alignment), kickban_hbox);
-
-    kickban_image = gtk_image_new_from_stock("gtk-delete", GTK_ICON_SIZE_BUTTON);
-    gtk_box_pack_start(GTK_BOX(kickban_hbox), kickban_image, FALSE, FALSE, 0);
-
-    kickban_label = gtk_label_new_with_mnemonic(_("Kickban"));
-    gtk_box_pack_start(GTK_BOX(kickban_hbox), kickban_label, FALSE, FALSE, 0);
-
-    gtk_label_set_justify(GTK_LABEL(kickban_label), GTK_JUSTIFY_LEFT);
-
-    gtk_box_pack_start(GTK_BOX(transfer_hbox[3]), kickban_button, FALSE, FALSE, 0);
-
-    g_signal_connect_swapped(GTK_OBJECT(kickban_button), "clicked",
-			     G_CALLBACK(kick_ban_button_clicked), widgets);
-
-
-    gtk_box_pack_start(GTK_BOX(transfer_hbox[3]), right_spacer_label[2], TRUE, TRUE, 0);
-
-
-    transfer_hbox[4] = gtk_hbox_new(TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox3), transfer_hbox[4], TRUE, TRUE, 0);
-
-    transfer_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
-    gtk_box_pack_start(GTK_BOX(transfer_hbox[4]), transfer_scrolled_window, TRUE, TRUE, 0);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(transfer_scrolled_window), 
-							    GTK_POLICY_AUTOMATIC, 
-							    GTK_POLICY_ALWAYS);
-    gtk_widget_set_size_request(transfer_scrolled_window, -1, 140);
-
-    widgets->transfer_textview = gtk_text_view_new();
-    gtk_container_add (GTK_CONTAINER (transfer_scrolled_window), widgets->transfer_textview);
-
-
-    gtk_widget_show_all(widgets->main_window);
-}
-*/
