@@ -98,7 +98,7 @@ void create_user_settings(struct w *widgets)
     username_button = make_button_with_entry(GTK_TABLE(widgets->usr_set_table),
                         		     widgets->user_set_entry[ent],
                     			     "gtk-refresh",
-					     "Username:",
+					     _("Username:"),
 					     "Crate a randomized username",
 					     0,1,a,b,350);
     a++; b++; ent++;
@@ -112,7 +112,7 @@ void create_user_settings(struct w *widgets)
     password_button = make_button_with_entry(GTK_TABLE(widgets->usr_set_table),
                         		     widgets->user_set_entry[ent],
                     			     "gtk-refresh",
-					     "Password:",
+					     _("Password:"),
 					     "Create a randomized password",
 					     0,1,a,b,350);
     a++; b++; ent++;
@@ -122,13 +122,13 @@ void create_user_settings(struct w *widgets)
 
 
     /* Group */
-    widgets->user_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->usr_set_table), _(" Group: "), 0,1,a,b,350);
+    widgets->user_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->usr_set_table), _("Group:"), 0,1,a,b,350);
     gtk_tooltips_set_tip(tooltips, widgets->user_set_entry[ent], "The group the user belongs to", NULL);
     a++; b++; ent++;
 
 
     /* Comment */
-    widgets->user_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->usr_set_table), _(" Comment: "), 0,1,a,b,350);
+    widgets->user_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->usr_set_table), _("Comment:"), 0,1,a,b,350);
     gtk_tooltips_set_tip(tooltips, widgets->user_set_entry[ent], "A comment about the user", NULL);
     a++; b++; ent++;
 
@@ -136,25 +136,25 @@ void create_user_settings(struct w *widgets)
     a++; b++; ent++; // Let this be for now
 
     /* Shell combo */    
-    widgets->user_set_combo[comb] = make_label_textcombo_label(GTK_TABLE(widgets->usr_set_table), _(" Shell: "), 0,1,a,b, 80);
+    widgets->user_set_combo[comb] = make_label_textcombo_label(GTK_TABLE(widgets->usr_set_table), _("Shell:"), 0,1,a,b, 80);
     populate_shell_combo(widgets->user_set_combo[comb]);
     a++; b++; comb++;
 
     /* Require password */
-    widgets->user_set_checkbutton[check] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), _(" Require password: "), 0,1,a,b);
+    widgets->user_set_checkbutton[check] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), _("Require password:"), 0,1,a,b);
     a++; b++; check++;
 
     /* Show user in statistics */
-    widgets->user_set_checkbutton[check] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), _(" Show user in statistics: "), 0,1,a,b);
+    widgets->user_set_checkbutton[check] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), _("Show user in statistics:"), 0,1,a,b);
     a++; b++; check++;
 
     /* Max logins */
-    widgets->user_set_spinbutton[spin] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table),_(" Maximum logins: ") , 0,1,a,b,80);
+    widgets->user_set_spinbutton[spin] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table),_("Maximum logins:") , 0,1,a,b,80);
     gtk_tooltips_set_tip(tooltips, widgets->user_set_spinbutton[spin], "Maximum number of simultaneous logins this user can make", NULL);
     a++; b++; spin++;
 
     /* Allow logins from */
-    widgets->user_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->usr_set_table), _(" Allow logins from: "), 0,1,a,b,350);
+    widgets->user_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->usr_set_table), _("Allow logins from:"), 0,1,a,b,350);
     gtk_tooltips_set_tip(tooltips, widgets->user_set_entry[ent], _("All, None, IP, DNS name or CIDR-Address"), NULL);
     a++; b++; ent++;
 
@@ -163,22 +163,22 @@ void create_user_settings(struct w *widgets)
     if( use_ratio )
     {
 	/* Byte ratio */
-	widgets->user_set_spinbutton[spin] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table),_(" Byte ratio: ") , 0,1,a,b,80);
+	widgets->user_set_spinbutton[spin] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table),_("Byte ratio:") , 0,1,a,b,80);
 	gtk_tooltips_set_tip(tooltips, widgets->user_set_spinbutton[spin], "If set to 3 then the ratio is 3:1. 0 means unlimited.", NULL);
 	a++; b++; spin++;
 
 	/* Byte ratio credit */
-	widgets->user_set_spinbutton[spin] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table),_(" Byte ratio credit: ") , 0,1,a,b,80);
+	widgets->user_set_spinbutton[spin] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table),_("Byte ratio credit:") , 0,1,a,b,80);
 	gtk_tooltips_set_tip(tooltips, widgets->user_set_spinbutton[spin], "If set to 6 then the the user can download 6 times the byte ratio before uploading. 0 means no credit.", NULL);
 	a++; b++; spin++;
 
 	/* File ratio */
-	widgets->user_set_spinbutton[spin] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table),_(" File ratio: ") , 0,1,a,b,80);
+	widgets->user_set_spinbutton[spin] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table),_("File ratio:") , 0,1,a,b,80);
 	gtk_tooltips_set_tip(tooltips, widgets->user_set_spinbutton[spin], "If set to 9 then 9 files can be downloaded for every 1 file uploaded. 0 means unlimited.", NULL);
 	a++; b++; spin++;
 
 	/* File ratio credit */
-	widgets->user_set_spinbutton[spin] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table),_(" File ratio credit: ") , 0,1,a,b,80);
+	widgets->user_set_spinbutton[spin] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table),_("File ratio credit:") , 0,1,a,b,80);
 	gtk_tooltips_set_tip(tooltips, widgets->user_set_spinbutton[spin], "If set to 12 then then the user can download 12 times the file ratio before uploading. 0 means no credit.", NULL);
 	a++; b++; spin++;
     }
@@ -186,7 +186,7 @@ void create_user_settings(struct w *widgets)
     /* Fixme, Quota */
     if( use_quota )
     {
-    
+
 
     }
 
