@@ -30,6 +30,12 @@
 #include "allocate.h"
 #include "delete_server.h"
 #include "populate_servers.h"
+#include "select_first_server.h"
+#include "populate_server_settings.h"
+#include "populate_users.h"
+#include "select_first_user.h"
+#include "populate_user_settings.h"
+#include "populate_conf_tab.h"
 #include "reread_conf.h"
 
 extern char global_server_address[1024];
@@ -174,6 +180,14 @@ void delete_server(struct w *widgets)
 
 
     populate_servers(widgets);
+    select_first_server(widgets);
+    populate_server_settings(widgets);
+
+    populate_users(widgets);
+    select_first_user(widgets);
+    populate_user_settings(widgets);
+
+    populate_conf_tab(widgets);
 
     /* Update the server */
     reread_conf(widgets);
