@@ -278,17 +278,7 @@ void delete_user(struct w *widgets)
 	}
     }
 
-    /* Update the user list and the user settings */
-    populate_users(widgets);
-
-    select_first_user(widgets);
-
-    populate_user_settings(widgets);
-    
-    populate_conf_tab(widgets);
-
-    /* Update the server */
-    reread_conf(widgets);
+    /* Repopulations are done in the (do or dont) functions below */
 }
 
 
@@ -296,13 +286,11 @@ void dont_delete_system_user(struct w *widgets)
 {
     gtk_widget_destroy(widgets->del_system_user_question_window);
 
-    /* Update the user list and the user settings */
+    /* Update users, user settings and the conf tab */
     populate_users(widgets);
-
     select_first_user(widgets);
-
     populate_user_settings(widgets);
-    
+
     populate_conf_tab(widgets);
 
     /* Update the server */
@@ -397,13 +385,11 @@ void do_delete_system_user(GtkButton *button, struct w *widgets)
       g_free(utf8);
 
 
-    /* Update the user list and the user settings */
+    /* Update users, user settings and the conf tab */
     populate_users(widgets);
-
     select_first_user(widgets);
-
     populate_user_settings(widgets);
-    
+
     populate_conf_tab(widgets);
 
     /* Update the server */
