@@ -34,7 +34,9 @@ gchar *get_group_name(gchar *groupnr);
 
 char *encrypt_password(G_CONST_RETURN gchar *password);
 
-int fix_newlines_in_conf();
+void password_virtual_user(G_CONST_RETURN gchar *username, G_CONST_RETURN gchar *password);
+
+void delete_virtual_user(G_CONST_RETURN gchar *username);
 
 void randomize_username(struct w *widgets);
 
@@ -42,6 +44,8 @@ void randomize_password(struct w *widgets);
 
 char *random_string(int len);
 
+int fix_newlines_in_conf();
+
 int user_exists(G_CONST_RETURN gchar *username);
 
 int group_exists(G_CONST_RETURN gchar *username);
@@ -56,6 +60,4 @@ void exec_ssl(char *command, char descr[128]);
 
 void make_dir_chmod(gchar *directory, char perm[128]);
 
-int file_exists(char *entity);
-
 #endif
