@@ -130,14 +130,12 @@ int main(int argc, char *argv[])
     }
 
 
-    
     /* Create the main window */
     create_main_window(widgets);
-    
+
     /* Set ProFTPD Version */
     set_version(widgets);
 
-
     /* If proftpd has the mod_tls module we 
        create, show and use the TLS widgets */
     use_tls = using_tls();
@@ -183,7 +181,7 @@ int main(int argc, char *argv[])
 
    /* Add default certificate settings if they are missing */
    openssl_conf = g_strdup_printf("%s/certs/gadmin-proftpd-openssl.conf", GP_APPCONFDIR);
-   if( ! file_exists(openssl_conf) )
+   if( ! file_exists(openssl_conf) && use_tls )
    {
        info = g_strdup_printf("%s/certs", GP_APPCONFDIR);
        gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[15]), info);
@@ -306,6 +304,9 @@ int main(int argc, char *argv[])
 
     g_free(conf_path);
 
+    /* Make an automatic backup for this version of gadmin-proftpd */
+    backup_configuration(widgets);
+
 
     /* This functions adds the required SERVER_USER AND SERVER_GROUP */
     add_standard_users(widgets);
