@@ -292,7 +292,9 @@ void generate_cert(struct w *widgets)
     "echo '01' > serial\n",
     "rm -f *.pem\n",
 
-    "openssl req -new -x509 -extensions v3_ca -keyout cakey.pem -out cacert.pem -config ", openssl_config_path, " -batch -passout file:", passfile,"\n\n",
+    "openssl req -new -x509 -days ",
+    days, " -extensions v3_ca -keyout cakey.pem -out cacert.pem -config ",
+    openssl_config_path, " -batch -passout file:", passfile,"\n\n",
     NULL);
     fputs(openssl_script, fp);
     fclose(fp);
