@@ -76,7 +76,7 @@ void populate_server_settings(struct w *widgets)
        sprintf(address_buffer, "<VirtualHost %s>", global_server_address);
     else
        sprintf(address_buffer, global_server_address);
-     
+        
     port_buffer = allocate(8192+3);               
 
     sprintf(port_buffer, "Port %s", global_server_port);
@@ -584,6 +584,12 @@ void populate_server_settings(struct w *widgets)
     free(port_buffer);
 
 
+    /* Set MasqueradeAddress to off if not found */
+    if( ! found_maskaddr )
+      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[1]), 1);
+
+
+
     /* Add settings.conf values to the server settings. */
     settings_conf = g_strdup_printf("%s/settings.conf", GP_APPCONFDIR);
     if((fp=fopen(settings_conf, "r"))==NULL)
@@ -601,7 +607,7 @@ void populate_server_settings(struct w *widgets)
     if( conf_size > 1 )
     while(fgets(old_buffer, conf_size, fp)!=NULL)
     {
-	if( cmplowercase(old_buffer, "certificate_directory") )
+	if( cmplowercase(old_buffer, "certificate_directory") && use_tls )
 	{
 	    sscanf(old_buffer, "%*s %s", new_buffer);
 	    if( new_buffer[strlen(new_buffer)-1]=='\n' || new_buffer[strlen(new_buffer)-1]=='\r' )
@@ -868,8 +874,4 @@ void populate_server_settings(struct w *widgets)
 
     if( utf8!=NULL )
       g_free(utf8);
-
-    /* Set MasqueradeAddress to off if not found */
-    if( ! found_maskaddr )
-      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[1]), 1);
 }
