@@ -30,6 +30,12 @@ int conf_ok(gchar *file_path);
 
 void create_standard_conf_question(struct w *widgets);
 
+void backup_configuration(struct w *widgets);
+
+void force_configuration_backup(struct w *widgets);
+
+void restore_configuration(struct w *widgets);
+
 void add_standard_conf(struct w *widgets);
 
 void new_tls_module_conf();
