@@ -49,7 +49,7 @@ char * get_process_pid(char process[1024], char extmatch[1024])
 
     pid = allocate(1024);
     strcpy(pid, "0");
-    
+
     sub_proc_path = allocate(1024);
 
     num = scandir(PROC_PATH, &namelist, 0, alphasort);
@@ -119,15 +119,10 @@ int status_update(struct w *widgets)
 	if( utf8!=NULL )
 	  g_free(utf8);
 
-	/* Show non ftp usage */    
+	/* Show non ftp usage */
         info = g_strdup_printf(_("The server is deactivated.\n"));
 	utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
 
-
-//	transfer_textbuffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(widgets->transfer_textview));
-//	gtk_text_buffer_set_text(transfer_textbuffer, utf8, strlen(utf8));
-
-
 	g_free(info);
 	if( utf8!=NULL )
 	  g_free(utf8);
@@ -147,11 +142,8 @@ int status_update(struct w *widgets)
       }
     free(pid);
 
-
-
     /* The server is activated, insert ftpwho information in the treeview */
 
-    
     /* Add the scoreboard file if its missing to avoid useless message */
     path = g_strdup_printf("%s/%s", GP_VARDIR, "run/proftpd");
     if( file_exists(path) )
@@ -185,25 +177,16 @@ int status_update(struct w *widgets)
     g_free(path);
 
 
-
     /* FTP who update and total xferrates */
-    
     gtk_list_store_clear(GTK_LIST_STORE(widgets->transfer_store));
-    
-    
+
     cmd = g_strdup_printf("%s -v", FTPWHO_BINARY);
     if((fp=popen(cmd, "r"))==NULL)
     {
-
-	/* Show ftpwho error information in the textview */    
+	/* Show ftpwho error information in the textview */
         info = g_strdup_printf(_("Error running ftpwho -v.\n"));
 	utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
 
-
-//	transfer_textbuffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(widgets->transfer_textview));
-//	gtk_text_buffer_set_text(transfer_textbuffer, utf8, strlen(utf8));
-
-
         g_free(cmd);
 	g_free(info);
 	if( utf8!=NULL )
@@ -218,7 +201,7 @@ int status_update(struct w *widgets)
     tmp  = allocate(MAX_READ_POPEN+20000); /* +20000 for translations and filenames */
 
     while(fgets(line, MAX_READ_POPEN, fp)!=NULL)
-    {	
+    {
 	if( line==NULL || strlen(line) < 10
 	|| strstr(line, "FTP daemon [")  || strstr(line, "up for")
 	|| strstr(line, "Service class") || strstr(line, "no users connected") )
@@ -235,7 +218,7 @@ int status_update(struct w *widgets)
 	
 	    /* The line looks like this:
 	       7154 test [ 0m27s] (n/a) APPE 05 - Soundfile.ogg */
-	    
+
 	    /* Insert PID */
 	    sscanf(line, "%s", tmp);
 	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
@@ -300,7 +283,7 @@ int status_update(struct w *widgets)
 
 	    if( tmp[strlen(tmp)-1]=='\n' )
 	        tmp[strlen(tmp)-1]='\0';
-	    
+
 	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
 	    gtk_list_store_set(GTK_LIST_STORE(widgets->transfer_store), &iter, 5, utf8, -1);
 	    if( utf8!=NULL )
@@ -309,7 +292,7 @@ int status_update(struct w *widgets)
 
         /* Total Xferrates incoming/outgoing/total bandwidth usage */
         /* Assumes that the ftpwho output shows stor retr appe and on the next line KB/s */
-		
+
         /* Incoming transfers */
         if(  strstr(line, "KB/s: ") && incoming == 1 
         && ! strstr(line, "inf") && ! strstr(line, "nan") )
@@ -318,7 +301,7 @@ int status_update(struct w *widgets)
 	    {
 	        sscanf(line, "%*s %li", &in_val);
 	    }
-	    
+
 	    if( in_val > 0 )
 	    {
 		inxfer = inxfer+in_val;
@@ -394,11 +377,11 @@ int status_update(struct w *widgets)
     free(line);
     free(tmp);
 
-    
+
     /* Total bandwidth usage */
     if( totalxfer >= 0 )
     {
-	info = g_strdup_printf("\t\t %s %li", _(" Total KB/s: "), totalxfer);
+	info = g_strdup_printf("  %s %li", _("Total Kbytes/sec:"), totalxfer);
         utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
 
 	gtk_label_set_text(GTK_LABEL(widgets->total_bandwidth_label), utf8);
@@ -410,8 +393,8 @@ int status_update(struct w *widgets)
 
     /* Total incoming xfers */
     if( inxfer >= 0 )
-    {    
-        info = g_strdup_printf("\t\t\t %s %li", _(" Incoming KB/s: "), inxfer);
+    {
+        info = g_strdup_printf("\t %s %li", _("Incoming Kbytes/sec:"), inxfer);
         utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
 
 	gtk_label_set_text(GTK_LABEL(widgets->total_incoming_label), utf8);
@@ -424,7 +407,7 @@ int status_update(struct w *widgets)
     /* Total outgoing xfers */
     if( outxfer >= 0 )
     {
-        info = g_strdup_printf("\t\t\t %s %li", _(" Outgoing KB/s: "), outxfer);
+        info = g_strdup_printf("\t %s %li  ", _("Outgoing Kbytes/sec:"), outxfer);
         utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
 
 	gtk_label_set_text(GTK_LABEL(widgets->total_outgoing_label), utf8);
